==> photo_view-0.0.11.tar.gz: example/lib/screens/full_screen_examples.dart <==
import 'package:flutter/material.dart';
import 'package:photo_view/photo_view.dart';
import './app_bar.dart';

class FullScreenExamples extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: <Widget>[
          const ExampleAppBar(
            title: "Full Screen Examples",
            showGoBack: true,
          ),
          Expanded(
              child: ListView(
            children: <Widget>[
              ExampleButtonNode(
                  title: "Large Image",
                  onPressed: () {
                    Navigator.push(
                        context,
                        MaterialPageRoute(
                          builder: (context) => const FullScreenWrapper(
                                imageProvider:
                                    const AssetImage("assets/large-image.jpg"),
                              ),
                        ));
                  }),
              ExampleButtonNode(
                  title: "Small Image (custom background)",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => const FullScreenWrapper(
                              imageProvider:
                                  const AssetImage("assets/small-image.jpg"),
                              backgroundColor: Colors.pinkAccent,
                            ),
                      ),
                    );
                  }),
              ExampleButtonNode(
                  title: "Image from the internet",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => const FullScreenWrapper(
                              imageProvider: const NetworkImage(
                                  "https://source.unsplash.com/900x1600/?camera,paper"),
                            ),
                      ),
                    );
                  }),
              ExampleButtonNode(
                  title: "Animated GIF",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => const FullScreenWrapper(
                              imageProvider:
                                  const AssetImage("assets/peanut.gif"),
                              backgroundColor: Colors.white,
                              maxScale: 2.0,
                            ),
                      ),
                    );
                  }),
              ExampleButtonNode(
                  title: "Limited scale",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => FullScreenWrapper(
                              imageProvider:
                                  const AssetImage("assets/large-image.jpg"),
                              minScale: PhotoViewComputedScale.contained * 0.8,
                              maxScale: PhotoViewComputedScale.covered * 1.1,
                            ),
                      ),
                    );
                  }),
              ExampleButtonNode(
                  title: "Custom Initial scale",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => FullScreenWrapper(
                              imageProvider:
                                  const AssetImage("assets/large-image.jpg"),
                              initialScale:
                                  PhotoViewComputedScale.contained * 0.9,
                            ),
                      ),
                    );
                  }),
            ],
          ))
        ],
      ),
    );
  }
}

class ExampleButtonNode extends StatelessWidget {
  final String title;
  final Function onPressed;

  const ExampleButtonNode({
    this.title,
    this.onPressed,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
        margin: const EdgeInsets.symmetric(
          vertical: 20.0,
        ),
        child: Column(
          children: <Widget>[
            Text(
              title,
              style: const TextStyle(
                  color: Colors.black,
                  fontSize: 21.0,
                  fontWeight: FontWeight.w600),
            ),
            Container(
                margin: const EdgeInsets.only(
                  top: 10.0,
                ),
                child: RaisedButton(
                  onPressed: onPressed,
                  child: const Text("Open example"),
                  color: Colors.amber,
                ))
          ],
        ));
  }
}

class FullScreenWrapper extends StatelessWidget {
  final ImageProvider imageProvider;
  final Widget loadingChild;
  final Color backgroundColor;
  final dynamic minScale;
  final dynamic maxScale;
  final dynamic initialScale;

  const FullScreenWrapper(
      {this.imageProvider,
      this.loadingChild,
      this.backgroundColor,
      this.minScale,
      this.maxScale,
      this.initialScale});

  @override
  Widget build(BuildContext context) {
    return Container(
        constraints: BoxConstraints.expand(
          height: MediaQuery.of(context).size.height,
        ),
        child: PhotoView(
          imageProvider: imageProvider,
          loadingChild: loadingChild,
          backgroundColor: backgroundColor,
          minScale: minScale,
          maxScale: maxScale,
          initialScale: initialScale,
        ));
  }
}

==> photo_view-0.1.0.tar.gz: example/lib/screens/full_screen_examples.dart <==
import 'package:flutter/material.dart';
import 'package:photo_view/photo_view.dart';
import './app_bar.dart';

class FullScreenExamples extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: <Widget>[
          const ExampleAppBar(
            title: "Full Screen Examples",
            showGoBack: true,
          ),
          Expanded(
              child: ListView(
            children: <Widget>[
              ExampleButtonNode(
                  title: "Large Image",
                  onPressed: () {
                    Navigator.push(
                        context,
                        MaterialPageRoute(
                          builder: (context) => const FullScreenWrapper(
                                imageProvider:
                                    const AssetImage("assets/large-image.jpg"),
                              ),
                        ));
                  }),
              ExampleButtonNode(
                  title: "Small Image (custom background)",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => const FullScreenWrapper(
                              imageProvider:
                                  const AssetImage("assets/small-image.jpg"),
                              backgroundDecoration: BoxDecoration(
                                  gradient: LinearGradient(
                                colors: <Color>[Colors.white, Colors.grey],
                                stops: [0.1, 1.0],
                              )),
                            ),
                      ),
                    );
                  }),
              ExampleButtonNode(
                  title: "Image from the internet",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => const FullScreenWrapper(
                              imageProvider: const NetworkImage(
                                  "https://source.unsplash.com/900x1600/?camera,paper"),
                            ),
                      ),
                    );
                  }),
              ExampleButtonNode(
                  title: "Animated GIF",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => const FullScreenWrapper(
                              imageProvider:
                                  const AssetImage("assets/peanut.gif"),
                              backgroundDecoration:
                                  BoxDecoration(color: Colors.white),
                              maxScale: 2.0,
                            ),
                      ),
                    );
                  }),
              ExampleButtonNode(
                  title: "Limited scale",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => FullScreenWrapper(
                              imageProvider:
                                  const AssetImage("assets/large-image.jpg"),
                              minScale: PhotoViewComputedScale.contained * 0.8,
                              maxScale: PhotoViewComputedScale.covered * 1.1,
                            ),
                      ),
                    );
                  }),
              ExampleButtonNode(
                  title: "Custom Initial scale",
                  onPressed: () {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => FullScreenWrapper(
                              imageProvider:
                                  const AssetImage("assets/large-image.jpg"),
                              initialScale:
                                  PhotoViewComputedScale.contained * 0.7,
                            ),
                      ),
                    );
                  }),
            ],
          ))
        ],
      ),
    );
  }
}

class ExampleButtonNode extends StatelessWidget {
  const ExampleButtonNode({
    this.title,
    this.onPressed,
  });

  final String title;
  final Function onPressed;

  @override
  Widget build(BuildContext context) {
    return Container(
        margin: const EdgeInsets.symmetric(
          vertical: 20.0,
        ),
        child: Column(
          children: <Widget>[
            Text(
              title,
              style: const TextStyle(
                  color: Colors.black,
                  fontSize: 21.0,
                  fontWeight: FontWeight.w600),
            ),
            Container(
                margin: const EdgeInsets.only(
                  top: 10.0,
                ),
                child: RaisedButton(
                  onPressed: onPressed,
                  child: const Text("Open example"),
                  color: Colors.amber,
                ))
          ],
        ));
  }
}

class FullScreenWrapper extends StatelessWidget {
  const FullScreenWrapper(
      {this.imageProvider,
      this.loadingChild,
      this.backgroundDecoration,
      this.minScale,
      this.maxScale,
      this.initialScale});

  final ImageProvider imageProvider;
  final Widget loadingChild;
  final Decoration backgroundDecoration;
  final dynamic minScale;
  final dynamic maxScale;
  final dynamic initialScale;

  @override
  Widget build(BuildContext context) {
    return Container(
        constraints: BoxConstraints.expand(
          height: MediaQuery.of(context).size.height,
        ),
        child: PhotoView(
          imageProvider: imageProvider,
          loadingChild: loadingChild,
          backgroundDecoration: backgroundDecoration,
          minScale: minScale,
          maxScale: maxScale,
          initialScale: initialScale,
        ));
  }
}
